import * as api from './api';
import { dict, UserPageQuery, AddReq, DelReq, EditReq, compute, CreateCrudOptionsProps, CreateCrudOptionsRet } from '@fast-crud/fast-crud';
import { inject, nextTick, ref } from 'vue';
import { successMessage } from '/@/utils/message';
import { BaseColumn } from '/@/views/adManage/utils/commonTabColumn.js';

export const createCrudOptions = function ({ crudExpose, context }: CreateCrudOptionsProps): CreateCrudOptionsRet {
	const pageRequest = async (query: UserPageQuery) => {
		query.campaign = context.campaignId
		return await api.GetList(query);
	};
	const editRequest = async ({ form, row }: EditReq) => {
		form.id = row.id;
		return await api.UpdateObj(form);
	};
	const delRequest = async ({ row }: DelReq) => {
		return await api.DelObj(row.id);
	};
	const addRequest = async ({ form }: AddReq) => {
		return await api.AddObj(form);
	};

	//权限判定
	const hasPermissions = inject('$hasPermissions');

	return {
		crudOptions: {
			table: {
				height: 750
			},
			container: {
        fixedHeight: false
      },
			request: {
				pageRequest,
				addRequest,
				editRequest,
				delRequest,
			},
			toolbar: {
        buttons: {
					search: {
						show: true
					},
					compact: {
						show: false
					}
				}
			},
			rowHandle: {
				fixed: 'right',
				width: 80,
				buttons: {
					view: {
						show: false,
					},
					edit: {
						iconRight: 'Edit',
						type: 'text',
            text: null
						// show: hasPermissions('dictionary:Update'),
					},
					remove: {
						iconRight: 'Delete',
						type: 'text',
            text: null
						// show: hasPermissions('dictionary:Delete'),
					},
				},
			},
			columns: {
        adGroupName: {
          title: '广告组名称',
          column: {
            width: '150px'
          },
					search: {
						show: true,
						component: {
							props: {
								clearable: true
							}
						}
					},
					form: {
						rules: [{required: true, message:'必填项'}]
					}
        },
				state: {
					title: '状态'
				},
				defaultBid: {
					title: '默认竞价'
				},
				...BaseColumn
			}
		}
	}
}
